@@ -135,3 +135,44 @@ ops = {
     'date_tomorrow': lambda data, a: str_to_datetime(a).date() == datetime.utcnow().date() + timedelta(days=1),
     'date_is_empty': lambda data, a: a == ""
 }
+
+
+module_id_dict = {'Campaigns': '1', 'Invoice': '2', 'SalesOrder': '3', 'PurchaseOrder': '4', 'Quotes': '5', 'Faq': '6',
+                  'Vendors': '7', 'PriceBooks': '8', 'Calendar': '9', 'Leads': '10', 'Accounts': '11', 'Contacts': '12',
+                  'Potentials': '13', 'Products': '14', 'Documents': '15', 'Emails': '16', 'HelpDesk': '17',
+                  'Events': '18', 'Users': '19', 'Groups': '20', 'Currency': '21', 'DocumentFolders': '22',
+                  'CompanyDetails': '23', 'Services': '24', 'ServiceContracts': '25', 'PBXManager': '26',
+                  'ProjectMilestone': '27', 'ProjectTask': '28', 'Project': '29', 'Assets': '30', 'ModComments': '31',
+                  'SMSNotifier': '32', 'LineItem': '33', 'Tax': '34', 'ProductTaxes': '35', 'PolicyPlan': '36',
+                  'Commission': '37', 'AgentCommission': '38', 'VTERoundRobin': '41', 'VTESLALog': '42',
+                  'VTEButtons': '43', 'VTEEmailPreview': '46', 'VReports': '49', 'RepliedSMSLog': '51',
+                  'VTELabelEditor': '55', 'ToolbarIcons': '68', 'VTEFeedback': '88', 'AgentCommissionCFG': '90',
+                  'Predicting': '91', 'Notifications': '95'}
+
+
+def buildquery(json_object):
+    if 'field' in json_object.keys():
+        # In this case the json_object is an object which describes a single query
+        if json_object.get("operator") != 'BETWEEN':
+            return json_object.get("field") + " " + json_object.get("operator") + " '" + json_object.get("value") + "' "
+        else:
+            return json_object.get("field") + " " + json_object.get("operator") + " '" + json_object.get("value") + "' " + 'AND' + " '" + json_object.get("value2")+ "' "
+
+    # else it is an "condition+filters" JSON - Object
+    else:
+        i = 0
+        # result = "("
+        result = ""
+        filter_array = json_object.get("filters")
+        while i < len(filter_array):
+            # Add (maybe nested) expression
+            result += " " + buildquery(filter_array[i]) + " "
+
+            # if we are already at the end of our filters array, do not add condition string
+            # or we WOULD end up with something like ( a OR b OR c OR )
+
+            if i != len(filter_array) - 1:
+                result += json_object.get("condition")
+            i = i + 1
+        # result += ")"
+        return result
